@@ -17,7 +17,6 @@ use json::{self, JsonValue};
 use once_cell::sync::OnceCell;
 use ra_ap_ide::{TextRange, TextSize};
 use regex::Regex;
-use std;
 use std::fmt;
 use std::io;
 
@@ -236,10 +235,7 @@ impl CompilationError {
     }
 
     pub fn rendered(&self) -> String {
-        self.json["rendered"]
-            .as_str()
-            .unwrap_or_else(|| "")
-            .to_owned()
+        self.json["rendered"].as_str().unwrap_or("").to_owned()
     }
 
     /// Returns the actual type indicated by the error message or None if this isn't a type error.
@@ -375,12 +371,7 @@ fn line_and_column(
 ) -> (usize, usize) {
     let text = &text[..usize::from(position)];
     let line = text.lines().count();
-    let mut column = text
-        .lines()
-        .last()
-        .map(|line| count_columns(&line))
-        .unwrap_or(0)
-        + 1;
+    let mut column = text.lines().last().map(count_columns).unwrap_or(0) + 1;
     if line == 1 {
         column += first_line_column_offset;
     }
